def merge_dicts(dict1: dict, dict2: dict):
    new_dict = { **dict1, **dict2 }
    union_keys = set(dict1.keys()) & set(dict2.keys())

    for key in union_keys:
        dict1_value = dict1[key]
        dict2_value = dict2[key]
        
        if isinstance(dict1_value, dict) and isinstance(dict2_value, dict):
            new_dict[key] = merge_dicts(dict1_value, dict2_value)
        elif dict2_value is None:
            del new_dict[key]

    return new_dict



from pathlib import Path
from os import getcwd

HOME_DIR = Path.home()
ROOT_DIR = Path(__file__).resolve().parent.parent
CUR_DIR = getcwd()

DOCS_PATH = f'{ROOT_DIR}/resources/docs.txt'
PACKAGE_FILE = f'{CUR_DIR}/.ezdeps.json'
RC_FILE = f'{Path.home()}/.ezdepsrc'



from .utils.cli import get_setup_params
from .docs import print_docs
from .manager import Manager

from .install import install
from .uninstall import uninstall
from .update import update
from .build import build
from .publish import publish

setup_params = get_setup_params()
directive = setup_params and setup_params['directive']
directive_params = setup_params and setup_params['directive_params']
params = setup_params and setup_params['params']

if not directive:
    print_docs()
    exit()

file_path = 'f' in params and params['f']
rc_path = 'r' in params and params['r']
manager = Manager(file_path, rc_path)

if directive == 'install':
    install(manager, directive_params, params)
elif directive == 'uninstall':
    uninstall(manager, directive_params, params)
elif directive == 'update':
    update(manager, directive_params, params)
elif directive == 'build':
    build(manager)
    if directive_params == ['publish']:
        publish(manager, params)
elif directive == 'publish':
    publish(manager, params)
else:
    raise Exception(f'Unexpected directive `{directive}`')

manager.write()
